==> keycloak-model-map-18.0.0-sources.jar: org/keycloak/models/map/realm/entity/MapRequiredActionProviderEntityFieldDelegate.java <==
package org.keycloak.models.map.realm.entity;
public class MapRequiredActionProviderEntityFieldDelegate extends org.keycloak.models.map.common.UpdatableEntity.Impl implements org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity> entityFieldDelegate;
    public MapRequiredActionProviderEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getAlias() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.ALIAS);
    }
    @SuppressWarnings("unchecked") @Override public void setAlias(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.ALIAS, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getName() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.NAME);
    }
    @SuppressWarnings("unchecked") @Override public void setName(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.NAME, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getProviderId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.PROVIDER_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setProviderId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.PROVIDER_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public Integer getPriority() {
        return (Integer) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.PRIORITY);
    }
    @SuppressWarnings("unchecked") @Override public void setPriority(Integer p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.PRIORITY, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean isEnabled() {
        return (Boolean) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.ENABLED);
    }
    @SuppressWarnings("unchecked") @Override public void setEnabled(Boolean p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.ENABLED, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean isDefaultAction() {
        return (Boolean) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.DEFAULT_ACTION);
    }
    @SuppressWarnings("unchecked") @Override public void setDefaultAction(Boolean p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.DEFAULT_ACTION, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Map<String,String> getConfig() {
        return (java.util.Map<String,String>) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.CONFIG);
    }
    @SuppressWarnings("unchecked") @Override public void setConfig(java.util.Map<String,String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.CONFIG, p0);
    }
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/realm/entity/MapRequiredActionProviderEntityFieldDelegate.java <==
package org.keycloak.models.map.realm.entity;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapRequiredActionProviderEntityFieldDelegate extends org.keycloak.models.map.common.UpdatableEntity.Impl implements org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity> entityFieldDelegate;
    public MapRequiredActionProviderEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @Override public boolean isUpdated() {
        return entityFieldDelegate.isUpdated();
    }
    @Override public void clearUpdatedFlag() {
        entityFieldDelegate.clearUpdatedFlag();
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getAlias() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.ALIAS);
    }
    @SuppressWarnings("unchecked") @Override public void setAlias(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.ALIAS, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getName() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.NAME);
    }
    @SuppressWarnings("unchecked") @Override public void setName(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.NAME, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getProviderId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.PROVIDER_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setProviderId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.PROVIDER_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public Integer getPriority() {
        return (Integer) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.PRIORITY);
    }
    @SuppressWarnings("unchecked") @Override public void setPriority(Integer p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.PRIORITY, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean isEnabled() {
        return (Boolean) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.ENABLED);
    }
    @SuppressWarnings("unchecked") @Override public void setEnabled(Boolean p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.ENABLED, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean isDefaultAction() {
        return (Boolean) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.DEFAULT_ACTION);
    }
    @SuppressWarnings("unchecked") @Override public void setDefaultAction(Boolean p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.DEFAULT_ACTION, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Map<String,String> getConfig() {
        return (java.util.Map<String,String>) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.CONFIG);
    }
    @SuppressWarnings("unchecked") @Override public void setConfig(java.util.Map<String,String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapRequiredActionProviderEntityFields.CONFIG, p0);
    }
}
